@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     ArchitectureType,
@@ -116,6 +116,7 @@ __all__ = (
     "DescribeWorldResponseTypeDef",
     "DescribeWorldTemplateRequestRequestTypeDef",
     "DescribeWorldTemplateResponseTypeDef",
+    "EnvironmentTypeDef",
     "FailedCreateSimulationJobRequestTypeDef",
     "FailureSummaryTypeDef",
     "FilterTypeDef",
@@ -205,7 +206,7 @@ __all__ = (
 BatchDeleteWorldsRequestRequestTypeDef = TypedDict(
     "BatchDeleteWorldsRequestRequestTypeDef",
     {
-        "worlds": List[str],
+        "worlds": Sequence[str],
     },
 )
 
@@ -220,7 +221,7 @@ BatchDeleteWorldsResponseTypeDef = TypedDict(
 BatchDescribeSimulationJobRequestRequestTypeDef = TypedDict(
     "BatchDescribeSimulationJobRequestRequestTypeDef",
     {
-        "jobs": List[str],
+        "jobs": Sequence[str],
     },
 )
 
@@ -298,14 +299,14 @@ _RequiredCreateDeploymentJobRequestRequestTypeDef = TypedDict(
     {
         "clientRequestToken": str,
         "fleet": str,
-        "deploymentApplicationConfigs": List["DeploymentApplicationConfigTypeDef"],
+        "deploymentApplicationConfigs": Sequence["DeploymentApplicationConfigTypeDef"],
     },
 )
 _OptionalCreateDeploymentJobRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDeploymentJobRequestRequestTypeDef",
     {
         "deploymentConfig": "DeploymentConfigTypeDef",
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -343,7 +344,7 @@ _RequiredCreateFleetRequestRequestTypeDef = TypedDict(
 _OptionalCreateFleetRequestRequestTypeDef = TypedDict(
     "_OptionalCreateFleetRequestRequestTypeDef",
     {
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -370,14 +371,15 @@ _RequiredCreateRobotApplicationRequestRequestTypeDef = TypedDict(
     "_RequiredCreateRobotApplicationRequestRequestTypeDef",
     {
         "name": str,
-        "sources": List["SourceConfigTypeDef"],
         "robotSoftwareSuite": "RobotSoftwareSuiteTypeDef",
     },
 )
 _OptionalCreateRobotApplicationRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRobotApplicationRequestRequestTypeDef",
     {
-        "tags": Dict[str, str],
+        "sources": Sequence["SourceConfigTypeDef"],
+        "tags": Mapping[str, str],
+        "environment": "EnvironmentTypeDef",
     },
     total=False,
 )
@@ -401,6 +403,7 @@ CreateRobotApplicationResponseTypeDef = TypedDict(
         "lastUpdatedAt": datetime,
         "revisionId": str,
         "tags": Dict[str, str],
+        "environment": "EnvironmentTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -415,6 +418,8 @@ _OptionalCreateRobotApplicationVersionRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRobotApplicationVersionRequestRequestTypeDef",
     {
         "currentRevisionId": str,
+        "s3Etags": Sequence[str],
+        "imageDigest": str,
     },
     total=False,
 )
@@ -437,6 +442,7 @@ CreateRobotApplicationVersionResponseTypeDef = TypedDict(
         "robotSoftwareSuite": "RobotSoftwareSuiteTypeDef",
         "lastUpdatedAt": datetime,
         "revisionId": str,
+        "environment": "EnvironmentTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -452,7 +458,7 @@ _RequiredCreateRobotRequestRequestTypeDef = TypedDict(
 _OptionalCreateRobotRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRobotRequestRequestTypeDef",
     {
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -481,7 +487,6 @@ _RequiredCreateSimulationApplicationRequestRequestTypeDef = TypedDict(
     "_RequiredCreateSimulationApplicationRequestRequestTypeDef",
     {
         "name": str,
-        "sources": List["SourceConfigTypeDef"],
         "simulationSoftwareSuite": "SimulationSoftwareSuiteTypeDef",
         "robotSoftwareSuite": "RobotSoftwareSuiteTypeDef",
     },
@@ -489,8 +494,10 @@ _RequiredCreateSimulationApplicationRequestRequestTypeDef = TypedDict(
 _OptionalCreateSimulationApplicationRequestRequestTypeDef = TypedDict(
     "_OptionalCreateSimulationApplicationRequestRequestTypeDef",
     {
+        "sources": Sequence["SourceConfigTypeDef"],
         "renderingEngine": "RenderingEngineTypeDef",
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
+        "environment": "EnvironmentTypeDef",
     },
     total=False,
 )
@@ -516,6 +523,7 @@ CreateSimulationApplicationResponseTypeDef = TypedDict(
         "lastUpdatedAt": datetime,
         "revisionId": str,
         "tags": Dict[str, str],
+        "environment": "EnvironmentTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -530,6 +538,8 @@ _OptionalCreateSimulationApplicationVersionRequestRequestTypeDef = TypedDict(
     "_OptionalCreateSimulationApplicationVersionRequestRequestTypeDef",
     {
         "currentRevisionId": str,
+        "s3Etags": Sequence[str],
+        "imageDigest": str,
     },
     total=False,
 )
@@ -554,6 +564,7 @@ CreateSimulationApplicationVersionResponseTypeDef = TypedDict(
         "renderingEngine": "RenderingEngineTypeDef",
         "lastUpdatedAt": datetime,
         "revisionId": str,
+        "environment": "EnvironmentTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -572,10 +583,10 @@ _OptionalCreateSimulationJobRequestRequestTypeDef = TypedDict(
         "outputLocation": "OutputLocationTypeDef",
         "loggingConfig": "LoggingConfigTypeDef",
         "failureBehavior": FailureBehaviorType,
-        "robotApplications": List["RobotApplicationConfigTypeDef"],
-        "simulationApplications": List["SimulationApplicationConfigTypeDef"],
-        "dataSources": List["DataSourceConfigTypeDef"],
-        "tags": Dict[str, str],
+        "robotApplications": Sequence["RobotApplicationConfigTypeDef"],
+        "simulationApplications": Sequence["SimulationApplicationConfigTypeDef"],
+        "dataSources": Sequence["DataSourceConfigTypeDef"],
+        "tags": Mapping[str, str],
         "vpcConfig": "VPCConfigTypeDef",
         "compute": "ComputeTypeDef",
     },
@@ -618,7 +629,7 @@ CreateSimulationJobResponseTypeDef = TypedDict(
 _RequiredCreateWorldExportJobRequestRequestTypeDef = TypedDict(
     "_RequiredCreateWorldExportJobRequestRequestTypeDef",
     {
-        "worlds": List[str],
+        "worlds": Sequence[str],
         "outputLocation": "OutputLocationTypeDef",
         "iamRole": str,
     },
@@ -627,7 +638,7 @@ _OptionalCreateWorldExportJobRequestRequestTypeDef = TypedDict(
     "_OptionalCreateWorldExportJobRequestRequestTypeDef",
     {
         "clientRequestToken": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -666,8 +677,8 @@ _OptionalCreateWorldGenerationJobRequestRequestTypeDef = TypedDict(
     "_OptionalCreateWorldGenerationJobRequestRequestTypeDef",
     {
         "clientRequestToken": str,
-        "tags": Dict[str, str],
-        "worldTags": Dict[str, str],
+        "tags": Mapping[str, str],
+        "worldTags": Mapping[str, str],
     },
     total=False,
 )
@@ -703,7 +714,7 @@ CreateWorldTemplateRequestRequestTypeDef = TypedDict(
         "name": str,
         "templateBody": str,
         "templateLocation": "TemplateLocationTypeDef",
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -725,7 +736,7 @@ DataSourceConfigTypeDef = TypedDict(
     {
         "name": str,
         "s3Bucket": str,
-        "s3Keys": List[str],
+        "s3Keys": Sequence[str],
     },
 )
 
@@ -851,7 +862,7 @@ _OptionalDeploymentLaunchConfigTypeDef = TypedDict(
     {
         "preLaunchFile": str,
         "postLaunchFile": str,
-        "environmentVariables": Dict[str, str],
+        "environmentVariables": Mapping[str, str],
     },
     total=False,
 )
@@ -959,6 +970,8 @@ DescribeRobotApplicationResponseTypeDef = TypedDict(
         "revisionId": str,
         "lastUpdatedAt": datetime,
         "tags": Dict[str, str],
+        "environment": "EnvironmentTypeDef",
+        "imageDigest": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -1022,6 +1035,8 @@ DescribeSimulationApplicationResponseTypeDef = TypedDict(
         "revisionId": str,
         "lastUpdatedAt": datetime,
         "tags": Dict[str, str],
+        "environment": "EnvironmentTypeDef",
+        "imageDigest": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -1177,6 +1192,14 @@ DescribeWorldTemplateResponseTypeDef = TypedDict(
     },
 )
 
+EnvironmentTypeDef = TypedDict(
+    "EnvironmentTypeDef",
+    {
+        "uri": str,
+    },
+    total=False,
+)
+
 FailedCreateSimulationJobRequestTypeDef = TypedDict(
     "FailedCreateSimulationJobRequestTypeDef",
     {
@@ -1201,7 +1224,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "name": str,
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -1271,7 +1294,7 @@ class LaunchConfigTypeDef(_RequiredLaunchConfigTypeDef, _OptionalLaunchConfigTyp
 ListDeploymentJobsRequestRequestTypeDef = TypedDict(
     "ListDeploymentJobsRequestRequestTypeDef",
     {
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "nextToken": str,
         "maxResults": int,
     },
@@ -1292,7 +1315,7 @@ ListFleetsRequestRequestTypeDef = TypedDict(
     {
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1312,7 +1335,7 @@ ListRobotApplicationsRequestRequestTypeDef = TypedDict(
         "versionQualifier": str,
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1331,7 +1354,7 @@ ListRobotsRequestRequestTypeDef = TypedDict(
     {
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1351,7 +1374,7 @@ ListSimulationApplicationsRequestRequestTypeDef = TypedDict(
         "versionQualifier": str,
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1370,7 +1393,7 @@ ListSimulationJobBatchesRequestRequestTypeDef = TypedDict(
     {
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1389,7 +1412,7 @@ ListSimulationJobsRequestRequestTypeDef = TypedDict(
     {
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1423,7 +1446,7 @@ ListWorldExportJobsRequestRequestTypeDef = TypedDict(
     {
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1442,7 +1465,7 @@ ListWorldGenerationJobsRequestRequestTypeDef = TypedDict(
     {
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1479,7 +1502,7 @@ ListWorldsRequestRequestTypeDef = TypedDict(
     {
         "nextToken": str,
         "maxResults": int,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1878,7 +1901,7 @@ SourceTypeDef = TypedDict(
 _RequiredStartSimulationJobBatchRequestRequestTypeDef = TypedDict(
     "_RequiredStartSimulationJobBatchRequestRequestTypeDef",
     {
-        "createSimulationJobRequests": List["SimulationJobRequestTypeDef"],
+        "createSimulationJobRequests": Sequence["SimulationJobRequestTypeDef"],
     },
 )
 _OptionalStartSimulationJobBatchRequestRequestTypeDef = TypedDict(
@@ -1886,7 +1909,7 @@ _OptionalStartSimulationJobBatchRequestRequestTypeDef = TypedDict(
     {
         "clientRequestToken": str,
         "batchPolicy": "BatchPolicyTypeDef",
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -1944,7 +1967,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
@@ -1994,7 +2017,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -2002,14 +2025,15 @@ _RequiredUpdateRobotApplicationRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateRobotApplicationRequestRequestTypeDef",
     {
         "application": str,
-        "sources": List["SourceConfigTypeDef"],
         "robotSoftwareSuite": "RobotSoftwareSuiteTypeDef",
     },
 )
 _OptionalUpdateRobotApplicationRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateRobotApplicationRequestRequestTypeDef",
     {
+        "sources": Sequence["SourceConfigTypeDef"],
         "currentRevisionId": str,
+        "environment": "EnvironmentTypeDef",
     },
     total=False,
 )
@@ -2032,6 +2056,7 @@ UpdateRobotApplicationResponseTypeDef = TypedDict(
         "robotSoftwareSuite": "RobotSoftwareSuiteTypeDef",
         "lastUpdatedAt": datetime,
         "revisionId": str,
+        "environment": "EnvironmentTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -2040,7 +2065,6 @@ _RequiredUpdateSimulationApplicationRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateSimulationApplicationRequestRequestTypeDef",
     {
         "application": str,
-        "sources": List["SourceConfigTypeDef"],
         "simulationSoftwareSuite": "SimulationSoftwareSuiteTypeDef",
         "robotSoftwareSuite": "RobotSoftwareSuiteTypeDef",
     },
@@ -2048,8 +2072,10 @@ _RequiredUpdateSimulationApplicationRequestRequestTypeDef = TypedDict(
 _OptionalUpdateSimulationApplicationRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateSimulationApplicationRequestRequestTypeDef",
     {
+        "sources": Sequence["SourceConfigTypeDef"],
         "renderingEngine": "RenderingEngineTypeDef",
         "currentRevisionId": str,
+        "environment": "EnvironmentTypeDef",
     },
     total=False,
 )
@@ -2074,6 +2100,7 @@ UpdateSimulationApplicationResponseTypeDef = TypedDict(
         "renderingEngine": "RenderingEngineTypeDef",
         "lastUpdatedAt": datetime,
         "revisionId": str,
+        "environment": "EnvironmentTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -2136,13 +2163,13 @@ VPCConfigResponseTypeDef = TypedDict(
 _RequiredVPCConfigTypeDef = TypedDict(
     "_RequiredVPCConfigTypeDef",
     {
-        "subnets": List[str],
+        "subnets": Sequence[str],
     },
 )
 _OptionalVPCConfigTypeDef = TypedDict(
     "_OptionalVPCConfigTypeDef",
     {
-        "securityGroups": List[str],
+        "securityGroups": Sequence[str],
         "assignPublicIp": bool,
     },
     total=False,
